from django.utils import timezone
from rest_framework import serializers
from foods.models import Food


class FoodSerializer(serializers.ModelSerializer):
    category_name = serializers.CharField(
        source="get_category_display", read_only=True
    )

    class Meta:
        model = Food
        fields = "__all__"

    def validate_expiration_date(self, value):
        # 消費期限が過去日の場合はエラー
        if value < timezone.now().date():
            raise serializers.ValidationError(
                "消費期限切れです"
            )
        return value

    def validate(self, data):
        # 連絡用に名前かSlack名を書くこと
        if not (
            data.get("owner_name")
            or data.get("owner_slack")
        ):
            raise serializers.ValidationError(
                "owner_nameかowner_slackを設定して下さい"
            )
        return data
